<?php

namespace App\Http\Controllers\Api\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\CertificateRequest;
use App\Http\Resources\CertificateListResource;
use App\Http\Resources\CertificateResource;
use App\Models\CertificateTemplate;
use Illuminate\Http\Request;
use Illuminate\Http\UploadedFile;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Str;
use Date;

class CertificateController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $search = request('search', '');
        if($search){
          $query = CertificateTemplate::where('status',1)->where('event_id',$search)->first();
          if($query){
            return new CertificateResource($query);
          }else{
            return false;
          }
        }else{
          $query = CertificateTemplate::query()->where('status',1)->first();
          return new CertificateResource($query);
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(CertificateRequest $request)
    {
        $data = $request->validated();
        $data['status'] =1;
        $data['event_id'] = (int)$request->event_id;

          /** @var \Illuminate\Http\UploadedFile $image */
          $file = $data['file'] ?? null;
          // Check if image was given and save on local file system
          if ($file) {
            $fileName = time() . '.' . $file->getClientOriginalExtension();
            $relPathAndName = $file->storePubliclyAs('/public/template', $fileName);
            $data['path'] = str_replace('public', 'storage', $relPathAndName);
          }

        $certificate = CertificateTemplate::create($data);
        return response()->json(['status'=>true,'certificate'=> new CertificateResource($certificate)]);
    }

    /**
     * Display the specified resource.
     *
     * @param \App\Models\CertificateTemplate $CertificateTemplate
     * @return \Illuminate\Http\Response
     */
    public function show(CertificateTemplate $video)
    {
        return new CertificateResource($video);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param \App\Models\CertificateTemplate      $video
     * @return \Illuminate\Http\Response
     */
    public function update(CertificateRequest $request, CertificateTemplate $video)
    {
        $data = $request->validated();
        $data['updated_at'] = new Date();

        /** @var \Illuminate\Http\UploadedFile $image */
        $file = $data['file'] ?? null;
        // Check if image was given and save on local file system
        if ($logo) {
          $fileName = time() . '.' . $file->getClientOriginalExtension();
          $relPathAndName = $file->storePubliclyAs('/public/template', $bannerName);
          $data['path'] = str_replace('public', 'storage', $relPathAndName);

            // If there is an old image, delete it
            if ($CertificateTemplate->path) {
                Storage::deleteDirectory('/public/' . dirname($CertificateTemplate->path));
            }
        }
        return new CertificateResource($CertificateTemplate);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param \App\Models\CertificateTemplate $video
     * @return \Illuminate\Http\Response
     */
    public function destroy(CertificateTemplate $video)
    {
        $product->delete();

        return response()->noContent();
    }

    private function saveImage(UploadedFile $image)
    {
        $path = 'images/' . Str::random();
        if (!Storage::exists($path)) {
            Storage::makeDirectory($path, 0755, true);
        }
        if (!Storage::putFileAS('public/' . $path, $image, $image->getClientOriginalName())) {
            throw new \Exception("Unable to save file \"{$image->getClientOriginalName()}\"");
        }

        return $path . '/' . $image->getClientOriginalName();
    }
}
