<?php

namespace App\Http\Controllers\Api\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\EvaluationRequest;
use App\Http\Resources\EvaluationListResource;
use App\Http\Resources\EvaluationResource;
use App\Models\Evaluation;
use App\Models\Plenary;
use Illuminate\Http\Request;
use Illuminate\Http\UploadedFile;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Str;
use Date;

class EvaluationController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $perPage = request('per_page', 10);
        $search = request('search', '');
        $sortField = request('sort_field', 'created_at');
        $sortDirection = request('sort_direction', 'desc');

        if($search == ''){
          $query = Evaluation::where(['status'=>1])->orderBy($sortField, $sortDirection)->paginate($perPage);
        }else{
          $query = Evaluation::where(['status'=>1,'event_id'=>$search])->orderBy($sortField, $sortDirection)->paginate($perPage);
        }
        return EvaluationListResource::collection($query);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(EvaluationRequest $request)
    {
      $data = $request->validated();
      $data['status'] =1;
      $data['event_id'] = (int)$request->event_id;
      $data['question'] = $request->question;
      $data['type'] = (int)$request->type;
      $data['mandatory'] = (int)$request->mandatory;
      $data['plenary'] = $request->plenary;

      $evaluation = Evaluation::create($data);

      if($data['type'] == 3 && count($data['plenary'])>0){
        foreach($data['plenary'] as $option){
          $plenary = new Plenary();
          $plenary->evaluation_id = $evaluation->id;
          $plenary->name = $option['name'];
          $plenary->status = 1;
          $plenary->save();
        }
      }

      return response()->json(['status'=>true,'evaluation'=> new EvaluationResource($evaluation)]);
    }

    /**
     * Display the specified resource.
     *
     * @param \App\Models\Evaluation $Evaluation
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        
      $evaluation = Evaluation::where(['status'=>1,'id'=>$id])->with('plenary')->first();
        return response()->json($evaluation);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param \App\Models\Evaluation      $event
     * @return \Illuminate\Http\Response
     */
    public function update(EvaluationRequest $request, Evaluation $evaluation)
    {
      $data = $request->validated();
      $data['updated_at'] = new Date();
      $evaluation->update($data);
      

      if($data['type']==3 && count($request['plenary'])>0){
        Plenary::where(['evaluation_id'=> $evaluation->id])->update(['status'=>0]);
        foreach($request['plenary'] as $option){
          $plenary = new Plenary();
          $plenary->evaluation_id = $evaluation->id;
          $plenary->name = $option['name'];
          $plenary->status = 1;
          $plenary->save();
        }
      }


      return new EvaluationResource($evaluation);
  }

    /**
     * Remove the specified resource from storage.
     *
     * @param \App\Models\Evaluation $event
     * @return \Illuminate\Http\Response
     */
    public function destroy(Evaluation $evaluation)
    {
      $evaluation->status = 0;
      if($evaluation->save()){
        return response(true);
      }else{
        return response(false);
      }
    }

    private function saveImage(UploadedFile $image)
    {
        $path = 'images/' . Str::random();
        if (!Storage::exists($path)) {
            Storage::makeDirectory($path, 0755, true);
        }
        if (!Storage::putFileAS('public/' . $path, $image, $image->getClientOriginalName())) {
            throw new \Exception("Unable to save file \"{$image->getClientOriginalName()}\"");
        }

        return $path . '/' . $image->getClientOriginalName();
    }
}
