<?php

namespace App\Http\Controllers\Api\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\CreateUserRequest;
// use App\Http\Requests\UpdateUserRequest;
use App\Http\Resources\UserResource;
use App\Http\Resources\UserListResource;
use App\Models\User;
use App\Models\UserDetails;
use App\Models\UserEvent;
use App\Models\UserEvaluation;
use App\Models\UserVideo;
use App\Models\UserCertificate;
use Illuminate\Http\Request;
use Illuminate\Http\UploadedFile;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Str;
use Maatwebsite\Excel\Facades\Excel;
use App\Imports\UsersImport;
use League\Csv\Reader;
use Illuminate\Support\Facades\DB;

class UserController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $perPage = request('per_page', 10);
        $search = request('search', '');
        $sortField = request('sort_field', 'updated_at');
        $sortDirection = request('sort_direction', 'desc');

        if($search != ''){
          $query = DB::table('users')
          ->join('user_event', 'users.id', '=', 'user_event.user_id')
          ->where('users.user_type', '!=', 'A')->where(['users.status'=> 1,'user_event.status'=> 1])
          ->where('user_event.event_id', $search)
          ->orderBy('users.updated_at', 'DESC')->paginate($perPage);
        }else{
          $query = DB::table('users')->join('user_event', 'users.id', '=', 'user_event.user_id')
          ->select('users.*')
          ->where('users.user_type', '!=', 'A')->where('users.status', 1)
          ->orderBy('users.updated_at', 'DESC')->paginate($perPage);
        }
        return UserListResource::collection($query);
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function getUser()
    {
        $query = Auth::user();
        return UserResource::collection($query);
    }


    public function show(User $user)
    {
        return new UserResource($user);
    }
    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */

     public function store(CreateUserRequest $request)
     {
        if ($request->file('csv_file')) {
          $file = $request->file('csv_file');
          $extension = $file->getClientOriginalExtension(); //Get extension of uploaded file
          $fileSize = $file->getSize(); //Get size of uploaded file in bytes
          //Checks to see that the valid file types and sizes were uploaded
          $this->checkUploadedFileProperties($extension, $fileSize);
          $import = new UsersImport();
          Excel::import($import, $request->file('csv_file'),$request->event_id);
          
          foreach($import->data as $data){
            $user = User::where(['registration_id'=>$data->registration_id,'status'=>1])->first();
            $user_event = UserEvent::firstOrCreate([
              'user_id' => $user->id,
              'event_id' =>  $request->event_id,
            ],[
              'status' => 1
            ]);
          }
          //Return a success response with the number if records uploaded
          return response()->json(['status'=>true,
          'message' => $import->data->count() ." records successfully uploaded"
          ]);
          } else {
          throw new \Exception('No file was uploaded', Response::HTTP_BAD_REQUEST);
          }
     }

     public function checkUploadedFileProperties($extension, $fileSize) : void
      {
        $valid_extension = array("csv", "xlsx"); //Only want csv and excel files
        // $maxFileSize = 2097152; // Uploaded file size limit is 2mb
        if (in_array(strtolower($extension), $valid_extension)) {
          // if ($fileSize <= $maxFileSize) { } 
          // else {
          //   throw new \Exception('No file was uploaded', Response::HTTP_REQUEST_ENTITY_TOO_LARGE); //413 error
          // }
        } else {
          throw new \Exception('Invalid file extension', Response::HTTP_UNSUPPORTED_MEDIA_TYPE); //415 error
        }
      }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param \App\Models\User         $user
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateUserRequest $request, User $user)
    {
        $data = $request->validated();

        if (!empty($data['password'])) {
            $data['password'] = Hash::make($data['password']);
        }
        $data['updated_by'] = $request->user()->id;

        $user->update($data);

        return new UserResource($user);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param \App\Models\User $user
     * @return \Illuminate\Http\Response
     */
    public function destroy(User $user)
    {
        $user->status = 0;
        if($user->save()){
          return response(true);
        }else{
          return response(false);
        }
    }


    public function evaluations(Request $request,$id){
      $event_id = UserEvent::select('event_id')->where(['user_id'=>$id,'status'=>1])->first();
      $evaluations = UserEvaluation::where(['event_id'=>$event_id,'user_id'=>$id,'status'=>1])->get();
      if($evaluations->count()){
        return response()->json(['status'=>true,'evaluations'=>$evaluations]);
      }else{
        return response()->json(['status'=>false,'evaluations'=>[]]);
      }
    }

    public function certificates(Request $request,$id){
      $event_id = UserEvent::select('event_id')->where(['user_id'=>$id,'status'=>1])->first();
      $certificates = UserCertificate::where(['event_id'=>$event_id,'user_id'=>$id,'status'=>1])->get();
      if($certificates->count()){
        return response()->json(['status'=>true,'certificates'=>$certificates]);
      }else{
        return response()->json(['status'=>false,'certificates'=>[]]);
      }
    }

    public function videos(Request $request,$id){
      $event_id = UserEvent::select('event_id')->where(['user_id'=>$id,'status'=>1])->first();
      $videos = UserVideo::where(['event_id'=>$event_id,'user_id'=>$id,'status'=>1])->get();
      if($videos->count()){
        return response()->json(['status'=>true,'videos'=>$videos]);
      }else{
        return response()->json(['status'=>false,'videos'=>[]]);
      }
    }

  function generateBarcodeNumber() {
      $number = mt_rand(1000000000, 9999999999); // better than rand()
  
      // call the same function if the barcode exists already
      if (barcodeNumberExists($number)) {
          return generateBarcodeNumber();
      }
  
      // otherwise, it's valid and can be used
      return $number;
  }
  
  function barcodeNumberExists($number) {
      // query the database and return a boolean
      // for instance, it might look like this in Laravel
      return User::whereBarcodeNumber($number)->exists();
  }
}
