<?php

namespace App\Http\Controllers\Api\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\VideoRequest;
use App\Http\Resources\VideoListResource;
use App\Http\Resources\VideoResource;
use App\Models\Video;
use Illuminate\Http\Request;
use Illuminate\Http\UploadedFile;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Str;
use Date;

class VideoController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $perPage = request('per_page', 10);
        $search = request('search', '');
        $sortField = request('sort_field', 'created_at');
        $sortDirection = request('sort_direction', 'desc');
        if($search == ''){
          $query = Video::where('status',1)->orderBy($sortField, $sortDirection)->paginate($perPage);
        }else{
          $query = Video::where(['status'=>1,'event_id'=>$search])->orderBy($sortField, $sortDirection)->paginate($perPage);
        }

        return VideoListResource::collection($query);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(VideoRequest $request)
    {
        $data = $request->validated();
        $data['status'] =1;
        $data['event_id'] = (int)$request->event_id;
        $video = Video::create($data);

        return response()->json(['status'=>true,'video'=> new VideoResource($video)]);

    }

    /**
     * Display the specified resource.
     *
     * @param \App\Models\Video $Video
     * @return \Illuminate\Http\Response
     */
    public function show(Video $video)
    {
        return new VideoResource($video);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param \App\Models\Video      $video
     * @return \Illuminate\Http\Response
     */
    public function update(EventRequest $request, Video $video)
    {
        $data = $request->validated();
        $data['updated_at'] = new Date();
        $video->update($data);

        return new VideoResource($video);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param \App\Models\Video $video
     * @return \Illuminate\Http\Response
     */
    public function destroy(Video $video)
    {
        $video->status = 0;
        if($video->save()){
          return response(true);
        }else{
          return response(false);
        }
    }
}
