<?php
namespace App\Http\Controllers\Api;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Auth;
use App\Models\User;
use App\Http\Resources\UserResource;
class AuthController extends Controller
{
    public function register(Request $request)
    {
        $requestData = $request->all();
        $validator = Validator::make($requestData,[
            'first_name' => 'required|max:55',
            'email' => 'email|required|unique:users',
            'password' => 'required|confirmed'
        ]);
        if ($validator->fails()) {
            return response()->json([
                'errors' => $validator->errors()
            ], 422);
        }
        $requestData['password'] = Hash::make($requestData['password']);
        $user = User::create($requestData);
        return response([ 'status' => true, 'message' => 'User successfully register.' ], 200);
    }
    public function login(Request $request)
    {
        $requestData = $request->all();
        $validator = Validator::make($requestData,[
            'email' => 'email|required',
            'password' => 'required'
        ]);
        if ($validator->fails()) {
            return response()->json([
                'errors' => $validator->errors()
            ], 422);
        }
        if(! auth()->attempt($requestData)){
            return response()->json(['error' => 'UnAuthorised Access'], 401);
        }
        if(auth()->user()->user_type == 'U'){
          $accessToken = auth()->user()->createToken('authToken')->accessToken;
          return response([
            'user' => new UserResource(auth()->user()),
            'access_token' => $accessToken
          ]);
        }else{
          return response([
            'message' => 'You don\'t have permission to authenticate as user'
          ], 403);
        }
    }

    public function adminlogin(Request $request)
    {
        $requestData = $request->all();
        $validator = Validator::make($requestData,[
            'email' => 'email|required',
            'password' => 'required'
        ]);
        if ($validator->fails()) {
            return response()->json([
                'errors' => $validator->errors()
            ], 422);
        }
        if(! auth()->attempt($requestData)){
            return response()->json(['error' => 'UnAuthorised Access'], 401);
        }
        if(auth()->user()->user_type == 'A'){
          $accessToken = auth()->user()->createToken('authToken')->accessToken;
          return response([
            'user' => new UserResource(auth()->user()),
            'access_token' => $accessToken
          ]);
        }else{
          return response([
            'message' => 'You don\'t have permission to authenticate as admin'
          ], 403);
        }
    }
  public function me(Request $request)
    {
        $user = $request->user();
        return response()->json(['user' => $user], 200);
    }
  public function logout (Request $request)
    {
        $token = auth()->user()->token();
        $token->revoke();
        $response = ['message' => 'You have been successfully logged out!'];
        return response($response, 200);
    }
}