import {createRouter, createWebHistory} from "vue-router";
// import AppLayout from '../components/AppLayout.vue'
import Login from "../views/user/Login.vue";
import Dashboard from "../views/user/Dashboard.vue";
import Videos from "../views/user/Videos.vue";
import VimeoPlayer from "../views/user/VimeoPlayer.vue";
import Certificates from "../views/user/Certificates.vue";
import EducationForm from "../views/user/EvaluationForm.vue";
import AdminLogin from "../views/admin/Login.vue";
import AdminDashboard from "../views/admin/Dashboard.vue";
import AdminEvents from "../views/admin/Events/Events.vue";
import AdminVideos from "../views/admin/Videos/Videos.vue";
import AdminUsers from "../views/admin/Users/Users.vue";
import AdminEvaluation from "../views/admin/Evaluation/Evaluation.vue";
import AdminCertificate from "../views/admin/Certificates/Certificate.vue";
import Settings from "../views/admin/Settings.vue";

import NotFound from "../views/NotFound.vue";
import store from "../store";
import Auth from '../../js/Auth.js';

const routes = [
  {
    path: '/',
    redirect: '/login'
  },
  {
    path: '/app',
    name: 'app',
    redirect: '/app/dashboard',
    meta: {
      requiresAuth: true,
      header:1,
      admin_header:0,
      admin_nav:0
    },
    children: [
      {
        path: 'dashboard',
        name: 'app.dashboard',
        component: Dashboard,
      },
      {
        path: 'videos',
        name: 'app.videos',
        component: Videos
      },
      {
        path: 'videos/:id',
        name: 'app.vimeo',
        component: VimeoPlayer
      },
      {
        path: 'certificates',
        name: 'app.certificates',
        component: Certificates
      },
      {
        path: 'education-form',
        name: 'app.educationForm',
        component: EducationForm
      }
    ]
  },
  {
    path: '/admin',
    name: 'admin',
    redirect: '/admin/dashboard',
    meta: {
      requiresAuth: true,
      header:0,
      admin_header:1,
      admin_nav:1
    },
    children: [
      {
        path: 'dashboard',
        name: 'admin.dashboard',
        component: AdminDashboard
      },
      {
        path: 'events',
        name: 'admin.events',
        component: AdminEvents
      },
      {
        path: 'videos',
        name: 'admin.videos',
        component: AdminVideos
      },
      {
        path: 'users',
        name: 'admin.users',
        component: AdminUsers
      },
      {
        path: 'evaluation',
        name: 'admin.evaluation',
        component: AdminEvaluation
      },
      {
        path: 'certificate',
        name: 'admin.certificate',
        component: AdminCertificate
      },
      {
        path: 'settings',
        name: 'admin.settings',
        component: Settings
      }
    ]
  },
  {
    path: '/login',
    name: 'login',
    component: Login,
    meta: {
      requiresGuest: true,
      header:0,
      admin_nav:0
    }
  },
  {
    path: '/admin/login',
    name: 'admin-login',
    component: AdminLogin,
    meta: {
      requiresGuest: true,
      header:0,
      admin_nav:0
    }
  },
  // {
  //   path: '/request-password',
  //   name: 'requestPassword',
  //   component: RequestPassword,
  //   meta: {
  //     requiresGuest: true
  //   }
  // },
  // {
  //   path: '/reset-password/:token',
  //   name: 'resetPassword',
  //   component: ResetPassword,
  //   meta: {
  //     requiresGuest: true
  //   }
  // },
  {
    path: '/:pathMatch(.*)',
    name: 'notfound',
    component: NotFound,
  }
];

const router = createRouter({
  history: createWebHistory(),
  routes
})

router.beforeEach((to, from, next) => {
  if (to.matched.some(record => record.meta.requiresAuth) ) {
      if (Auth.check()) {
          next();
          return;
      } else {
          router.push('/login');
      }
  } else {
      next();
  }
});

export default router;