import axiosClient from "../axios";
import Auth from '../../js/Auth.js';

export function getCurrentUser({commit}, data) {
  return axiosClient.get('/user', data)
    .then(({data}) => {
      // commit('setUser', data);
      return data;
    })
}

export function login({commit}, data) {
  return axiosClient.post('/login', data)
    .then(({data}) => {
      // commit('setUser', data.user);
      // commit('setToken', data.access_token);
      Auth.login(data.access_token,data.user); 
      console.log(data);
      return data;
    })
}

export function adminLogin({commit}, data) {
  return axiosClient.post('/admin/login', data)
    .then(({data}) => {
      // commit('setUser', data.user);
      // commit('setToken', data.token);
      Auth.login(data.access_token,data.user); 
      return data;
    })
}

export function logout({commit,state}) {
  return axiosClient.post('/logout')
    .then((response) => {
      Auth.logout(); 
      // commit('setToken', null)
      return response;
    })
}
// export function adminLogout({commit}) {
//   return axiosClient.post('/admin/logout')
//     .then((response) => {
//       Auth.logout(); 
//       // commit('setToken', null)
//       return response;
//     })
// }

export function getEventList({commit}) {
  return axiosClient.get('/admin/list/events')
    .then(({data}) => {
      commit('setEventList', data)
    })
}


export function getEvents({commit, state}, {url = null, search = '', per_page, sort_field, sort_direction} = {}) {
  commit('setEvents', [true])
  url = url || '/admin/events'
  const params = {
    per_page: state.events.limit,
  }
  return axiosClient.get(url, {
    params: {
      ...params,
      search, per_page, sort_field, sort_direction
    }
  })
    .then((response) => {
      commit('setEvents', [false, response.data])
    })
    .catch(() => {
      commit('setEvents', [false])
    })
}

export function getEvent({commit}, id) {
  return axiosClient.get(`/admin/events/${id}`)
}

export function createEvent({commit}, event) {
  if (event.banner instanceof File && event.logo instanceof File) {
    const form = new FormData();
    form.append('title', event.title);
    form.append('start_date', event.start_date);
    form.append('end_date', event.end_date);
    form.append('logo', event.logo);
    form.append('banner', event.banner);
    form.append('url', event.url);
    event = form;
  }
  return axiosClient.post('/admin/events', event)
}

export function deleteEvent({commit}, id) {
  return axiosClient.delete(`/admin/events/${id}`)
}

export function updateEvent({commit}, event) {
  const id = event.id
  if (event.banner instanceof File || event.logo instanceof File) {
    const form = new FormData();
    form.append('id', event.id);
    form.append('title', event.title);
    form.append('start_date', event.start_date);
    form.append('end_date', event.end_date);
    form.append('logo', event.logo);
    form.append('banner', event.banner);
    form.append('url', event.url);
    form.append('_method', 'PUT');
    event = form;
  }else {
    event._method = 'PUT'
  }
  return axiosClient.post(`/admin/events/${id}`, event)
}

export function getUsers({commit, state}, {url = null, search = '', per_page, sort_field, sort_direction} = {}) {
  commit('setUsers', [true])
  url = url || '/admin/users'
  const params = {
    per_page: state.users.limit,
  }
  return axiosClient.get(url, {
    params: {
      ...params,
      search, per_page, sort_field, sort_direction
    }
  })
    .then((response) => {
      commit('setUsers', [false, response.data])
    })
    .catch(() => {
      commit('setUsers', [false])
    })
}

export function createUser({commit}, user) {
  if (user.csv_file instanceof File) {
    const form = new FormData();
    form.append('event_id', user.event_id);
    form.append('csv_file', user.csv_file);
    user = form;
  }
  return axiosClient.post('/admin/users', user)
}

export function updateUser({commit}, user) {
  return axiosClient.put(`/users/${user.id}`, user)
}

export function getUser({commit}, id) {
  return axiosClient.get(`/admin/users/${id}`)
}

export function deleteUser({commit}, id) {
  return axiosClient.delete(`/admin/users/${id}`)
}

export function getVideos({commit, state}, {url = null, search = '', per_page, sort_field, sort_direction} = {}) {
  commit('setVideos', [true])
  url = url || '/admin/videos'
  const params = {
    per_page: state.videos.limit,
  }
  return axiosClient.get(url, {
    params: {
      ...params,
      search, per_page, sort_field, sort_direction
    }
  })
    .then((response) => {
      commit('setVideos', [false, response.data])
    })
    .catch(() => {
      commit('setVideos', [false])
    })
}

export function getVideo({commit}, id) {
  return axiosClient.get(`/admin/videos/${id}`)
}

export function createVideo({commit}, video) {
  return axiosClient.post('/admin/videos', video)
}

export function updateVideo({commit}, video) {
  return axiosClient.put(`/admin/videos/${video.id}`, video)
}

export function deleteVideo({commit}, id) {
  return axiosClient.delete(`/admin/videos/${id}`)
}

export function getEvaluations({commit, state}, {url = null, search = '', per_page, sort_field, sort_direction} = {}) {
  commit('setEvaluations', [true])
  url = url || '/admin/evaluations'
  const params = {
    per_page: state.evaluations.limit,
  }
  return axiosClient.get(url, {
    params: {
      ...params,
      search, per_page, sort_field, sort_direction
    }
  })
    .then((response) => {
      commit('setEvaluations', [false, response.data])
    })
    .catch(() => {
      commit('setEvaluations', [false])
    })
}

export function getEvaluation({commit}, id) {
  return axiosClient.get(`/admin/evaluations/${id}`)
}

export function createEvaluation({commit}, template) {
  return axiosClient.post('/admin/evaluations', template)
}

export function updateEvaluation({commit}, template) {
  return axiosClient.put(`/admin/evaluations/${template.id}`, template)
}

export function deleteEvaluation({commit}, template) {
  return axiosClient.delete(`/admin/evaluations/${template}`)
}


export function getTemplates({commit, state}, {url = null, search = ''} = {}) {
  commit('setTemplates', [true])
  url = url || '/admin/templates'
  return axiosClient.get(url, {
    params: {search}
  })
    .then((response) => {
      commit('setTemplates', [false, response.data])
    })
    .catch(() => {
      commit('setTemplates', [false])
    })
}

export function getTemplate({commit}, id) {
  return axiosClient.get(`/admin/templates/${id}`)
}

export function createTemplate({commit}, template) {
  if (template.file instanceof File) {
    const form = new FormData();
    form.append('event_id', template.event_id);
    form.append('file', template.file);
    template = form;
  }
  return axiosClient.post('/admin/templates', template)
}

export function updateTemplate({commit}, template) {
  return axiosClient.put(`/admin/templates/${template.id}`, template)
}

export function deleteTemplate({commit}, template) {
  return axiosClient.delete(`/admin/templates/${template.id}`)
}

export function getUserEvaluation({commit, state}, id) {
  return axiosClient.get(`/admin/user/evaluations/${id}`);
}
export function getUserVideos({commit, state}, id) {
  return axiosClient.get(`/admin/user/videos/${id}`);
}
export function getAuthVideos({commit, state}, {url = null, search = '', per_page, sort_field, sort_direction} = {}) {
  commit('setAuthVideos', [true])
  url = url || '/videos'
  const params = {
    per_page: state.videos.limit,
  }
  return axiosClient.get(url, {
    params: {
      ...params,
      search, per_page, sort_field, sort_direction
    }
  })
    .then((data) => {
      commit('setAuthVideos', [false, data])
    })
    .catch(() => {
      commit('setAuthVideos', [false])
    });
}
export function getAuthEvaluation({commit, state}, {url = null, search = '', per_page, sort_field, sort_direction} = {}) {
  commit('setAuthEvaluation', [true])
  url = url || '/evaluations'
  const params = {
    per_page: state.evaluations.limit,
  }
  return axiosClient.get(url, {
    params: {
      ...params,
      search, per_page, sort_field, sort_direction
    }
  })
    .then((data) => {
      commit('setAuthEvaluation', [false, data])
    })
    .catch(() => {
      commit('setAuthEvaluation', [false])
    });
}
export function getVimeoVideo({commit}, id) {
  return axiosClient.get(`/videos/${id}`)
}
export function vimeoInfo({commit}, videoId) {
  return axiosClient.get(`https://vimeo.com/api/v2/video/${videoId}.json`)
}